@@ -195,7 +195,14 @@ def _process_baremetal_data(data_source, groups, hostvars):
             LOG.debug("Failed to parse JSON or YAML: %s", e)
             raise Exception("Failed to parse JSON or YAML")
 
+    node_names = os.environ.get('BIFROST_NODE_NAMES', None)
+    if node_names:
+        node_names = node_names.split(',')
+
     for name in file_data:
+        if node_names and name not in node_names:
+            continue
+
         host = file_data[name]
         # Perform basic validation
         node_net_data = host.get('node_network_data')
@@ -224,6 +231,10 @@ def _process_baremetal_data(data_source, groups, hostvars):
 
 def _process_baremetal_csv(data_source, groups, hostvars):
     """Process legacy baremetal.csv format"""
+    node_names = os.environ.get('BIFROST_NODE_NAMES', None)
+    if node_names:
+        node_names = node_names.split(',')
+
     with open(data_source, 'r') as file_data:
         for row in csv.reader(file_data, delimiter=','):
             if not row:
@@ -253,6 +264,10 @@ def _process_baremetal_csv(data_source, groups, hostvars):
             properties['cpu_arch'] = "x86_64"
             host['uuid'] = _val_or_none(row, 9)
             host['name'] = _val_or_none(row, 10)
+
+            if node_names and host['name'] not in node_names:
+                continue
+
             host['host_groups'] = ["baremetal"]
             host['ipv4_address'] = _val_or_none(row, 11)
             if ('ipv4_address' not in host or
@@ -310,16 +325,23 @@ def _process_baremetal_csv(data_source, groups, hostvars):
 
 def _identify_shade_auth():
     """Return shade credentials"""
-    # Note(TheJulia): A logical progression is to support a user defining
-    # an environment variable that triggers use of os-client-config to allow
-    # environment variables or clouds.yaml auth configuration.  This could
-    # potentially be passed in as variables which could then be passed
-    # to modules for authentication allowing the basic tooling to be
-    # utilized in the context of a larger cloud supporting ironic.
+    if os.environ.get('OS_CLOUD'):
+        return {}
+    endpoint = os.getenv('OS_URL',
+                         os.getenv('IRONIC_URL', "http://localhost:6385/"))
     options = dict(
         auth_type="None",
-        auth=dict(endpoint="http://localhost:6385/",)
+        auth=dict(endpoint=endpoint,)
     )
+    if os.environ.get('OS_AUTH_URL'):
+        options['auth_type'] = "password"
+        options['auth'] = dict(
+            username=os.getenv('OS_USERNAME', ""),
+            password=os.getenv('OS_PASSWORD', ""),
+            auth_url=os.getenv('OS_AUTH_URL', ""),
+            project_name=os.getenv('OS_PROJECT_NAME', ""),
+            domain_id=os.getenv('OS_USER_DOMAIN_NAME', ""),
+        )
     return options
 
 
@@ -328,6 +350,11 @@ def _process_shade(groups, hostvars):
     options = _identify_shade_auth()
     cloud = shade.operator_cloud(**options)
     machines = cloud.list_machines()
+
+    node_names = os.environ.get('BIFROST_NODE_NAMES', None)
+    if node_names:
+        node_names = node_names.split(',')
+
     for machine in machines:
         if 'properties' not in machine:
             machine = cloud.get_machine(machine['uuid'])
@@ -335,6 +362,10 @@ def _process_shade(groups, hostvars):
             name = machine['uuid']
         else:
             name = machine['name']
+
+        if node_names and name not in node_names:
+            continue
+
         new_machine = {}
         for key, value in machine.items():
             # NOTE(TheJulia): We don't want to pass infomrational links
